use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text);

use utf8;

$result_trees{'more_sections_than_nodes'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => '\\input texinfo @c -*-texinfo-*-
',
                  'type' => 'preamble_text'
                },
                {
                  'parent' => {},
                  'text' => '
',
                  'type' => 'preamble_text'
                }
              ],
              'parent' => {},
              'type' => 'preamble'
            }
          ],
          'parent' => {},
          'type' => 'preamble_before_setfilename'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => 'more_sections_than_nodes.info'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'parent' => {},
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'setfilename',
          'extra' => {
            'spaces_before_argument' => ' ',
            'text_arg' => 'more_sections_than_nodes.info'
          },
          'line_nr' => {
            'file_name' => 'more_sections_than_nodes.texi',
            'line_nr' => 3,
            'macro' => ''
          },
          'parent' => {}
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'parent' => {},
      'type' => 'text_root'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Top'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'Top'
          }
        ],
        'normalized' => 'Top',
        'spaces_before_argument' => ' '
      },
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 5,
        'macro' => ''
      },
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'top'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'top',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'cmdname' => 'menu',
          'contents' => [
            {
              'extra' => {
                'command' => {}
              },
              'parent' => {},
              'text' => '
',
              'type' => 'empty_line_after_command'
            },
            {
              'args' => [
                {
                  'parent' => {},
                  'text' => '* ',
                  'type' => 'menu_entry_leading_text'
                },
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'n c2'
                    }
                  ],
                  'parent' => {},
                  'type' => 'menu_entry_node'
                },
                {
                  'parent' => {},
                  'text' => '::',
                  'type' => 'menu_entry_separator'
                },
                {
                  'contents' => [
                    {
                      'contents' => [
                        {
                          'parent' => {},
                          'text' => '
'
                        }
                      ],
                      'parent' => {},
                      'type' => 'preformatted'
                    }
                  ],
                  'parent' => {},
                  'type' => 'menu_entry_description'
                }
              ],
              'extra' => {
                'menu_entry_description' => {},
                'menu_entry_node' => {
                  'node_content' => [
                    {}
                  ],
                  'normalized' => 'n-c2'
                }
              },
              'line_nr' => {
                'file_name' => 'more_sections_than_nodes.texi',
                'line_nr' => 9,
                'macro' => ''
              },
              'parent' => {},
              'type' => 'menu_entry'
            },
            {
              'args' => [
                {
                  'parent' => {},
                  'text' => '* ',
                  'type' => 'menu_entry_leading_text'
                },
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'n c3'
                    }
                  ],
                  'parent' => {},
                  'type' => 'menu_entry_node'
                },
                {
                  'parent' => {},
                  'text' => '::',
                  'type' => 'menu_entry_separator'
                },
                {
                  'contents' => [
                    {
                      'contents' => [
                        {
                          'parent' => {},
                          'text' => '
'
                        }
                      ],
                      'parent' => {},
                      'type' => 'preformatted'
                    }
                  ],
                  'parent' => {},
                  'type' => 'menu_entry_description'
                }
              ],
              'extra' => {
                'menu_entry_description' => {},
                'menu_entry_node' => {
                  'node_content' => [
                    {}
                  ],
                  'normalized' => 'n-c3'
                }
              },
              'line_nr' => {
                'file_name' => 'more_sections_than_nodes.texi',
                'line_nr' => 10,
                'macro' => ''
              },
              'parent' => {},
              'type' => 'menu_entry'
            },
            {
              'args' => [
                {
                  'parent' => {},
                  'text' => '* ',
                  'type' => 'menu_entry_leading_text'
                },
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'n c3 s1 s2'
                    }
                  ],
                  'parent' => {},
                  'type' => 'menu_entry_node'
                },
                {
                  'parent' => {},
                  'text' => '::',
                  'type' => 'menu_entry_separator'
                },
                {
                  'contents' => [
                    {
                      'contents' => [
                        {
                          'parent' => {},
                          'text' => '
'
                        }
                      ],
                      'parent' => {},
                      'type' => 'preformatted'
                    }
                  ],
                  'parent' => {},
                  'type' => 'menu_entry_description'
                }
              ],
              'extra' => {
                'menu_entry_description' => {},
                'menu_entry_node' => {
                  'node_content' => [
                    {}
                  ],
                  'normalized' => 'n-c3-s1-s2'
                }
              },
              'line_nr' => {
                'file_name' => 'more_sections_than_nodes.texi',
                'line_nr' => 11,
                'macro' => ''
              },
              'parent' => {},
              'type' => 'menu_entry'
            },
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'menu'
                    }
                  ],
                  'extra' => {
                    'spaces_after_argument' => '
'
                  },
                  'parent' => {},
                  'type' => 'line_arg'
                }
              ],
              'cmdname' => 'end',
              'extra' => {
                'command_argument' => 'menu',
                'spaces_before_argument' => ' ',
                'text_arg' => 'menu'
              },
              'line_nr' => {
                'file_name' => 'more_sections_than_nodes.texi',
                'line_nr' => 12,
                'macro' => ''
              },
              'parent' => {}
            }
          ],
          'extra' => {
            'end_command' => {}
          },
          'line_nr' => {
            'file_name' => 'more_sections_than_nodes.texi',
            'line_nr' => 8,
            'macro' => ''
          },
          'parent' => {}
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 0,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 6,
        'macro' => ''
      },
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c1'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'chapter',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 1,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 14,
        'macro' => ''
      },
      'number' => 1,
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'n c2'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'n-c2'
          }
        ],
        'normalized' => 'n-c2',
        'spaces_before_argument' => ' '
      },
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 16,
        'macro' => ''
      },
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c2'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'chapter',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 1,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 17,
        'macro' => ''
      },
      'number' => 2,
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 's1'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'section',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 2,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 19,
        'macro' => ''
      },
      'number' => '2.1',
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'n c3'
            }
          ],
          'parent' => {},
          'type' => 'line_arg'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'n c3 s1 s2'
            }
          ],
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'parent' => {},
          'type' => 'line_arg'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'n c2'
            }
          ],
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'parent' => {},
          'type' => 'line_arg'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Top'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
',
            'spaces_before_argument' => ' '
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'n-c3'
          },
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'n-c3-s1-s2'
          },
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'n-c2'
          },
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'Top'
          }
        ],
        'normalized' => 'n-c3',
        'spaces_before_argument' => ' '
      },
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 21,
        'macro' => ''
      },
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c3'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'chapter',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'cmdname' => 'menu',
          'contents' => [
            {
              'extra' => {
                'command' => {}
              },
              'parent' => {},
              'text' => ' 
',
              'type' => 'empty_line_after_command'
            },
            {
              'args' => [
                {
                  'parent' => {},
                  'text' => '* ',
                  'type' => 'menu_entry_leading_text'
                },
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'n c3 s 2'
                    }
                  ],
                  'parent' => {},
                  'type' => 'menu_entry_node'
                },
                {
                  'parent' => {},
                  'text' => '::',
                  'type' => 'menu_entry_separator'
                },
                {
                  'contents' => [
                    {
                      'contents' => [
                        {
                          'parent' => {},
                          'text' => '
'
                        }
                      ],
                      'parent' => {},
                      'type' => 'preformatted'
                    }
                  ],
                  'parent' => {},
                  'type' => 'menu_entry_description'
                }
              ],
              'extra' => {
                'menu_entry_description' => {},
                'menu_entry_node' => {
                  'node_content' => [
                    {}
                  ],
                  'normalized' => 'n-c3-s-2'
                }
              },
              'line_nr' => {
                'file_name' => 'more_sections_than_nodes.texi',
                'line_nr' => 25,
                'macro' => ''
              },
              'parent' => {},
              'type' => 'menu_entry'
            },
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'menu'
                    }
                  ],
                  'extra' => {
                    'spaces_after_argument' => '
'
                  },
                  'parent' => {},
                  'type' => 'line_arg'
                }
              ],
              'cmdname' => 'end',
              'extra' => {
                'command_argument' => 'menu',
                'spaces_before_argument' => ' ',
                'text_arg' => 'menu'
              },
              'line_nr' => {
                'file_name' => 'more_sections_than_nodes.texi',
                'line_nr' => 26,
                'macro' => ''
              },
              'parent' => {}
            }
          ],
          'extra' => {
            'end_command' => {}
          },
          'line_nr' => {
            'file_name' => 'more_sections_than_nodes.texi',
            'line_nr' => 24,
            'macro' => ''
          },
          'parent' => {}
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 1,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 22,
        'macro' => ''
      },
      'number' => 3,
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'C3 s1'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'section',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 2,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 28,
        'macro' => ''
      },
      'number' => '3.1',
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'n c3 s 2'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'n-c3-s-2'
          }
        ],
        'normalized' => 'n-c3-s-2',
        'spaces_before_argument' => ' '
      },
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 30,
        'macro' => ''
      },
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c3 s2'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'section',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 2,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 31,
        'macro' => ''
      },
      'number' => '3.2',
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c3 s3'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'section',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 2,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 33,
        'macro' => ''
      },
      'number' => '3.3',
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c4'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'chapter',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 1,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 35,
        'macro' => ''
      },
      'number' => 4,
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c3 s1'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'section',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 2,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 37,
        'macro' => ''
      },
      'number' => '4.1',
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c3 s1 s1'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'subsection',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 3,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 39,
        'macro' => ''
      },
      'number' => '4.1.1',
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'n c3 s1 s2'
            }
          ],
          'parent' => {},
          'type' => 'line_arg'
        },
        {
          'contents' => [],
          'parent' => {},
          'type' => 'line_arg'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'n c3'
            }
          ],
          'parent' => {},
          'type' => 'line_arg'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Top'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'n-c3-s1-s2'
          },
          undef,
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'n-c3'
          },
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'Top'
          }
        ],
        'normalized' => 'n-c3-s1-s2',
        'spaces_before_argument' => ' '
      },
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 41,
        'macro' => ''
      },
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'c3 s1 s2'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'subsection',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 3,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 42,
        'macro' => ''
      },
      'number' => '4.1.2',
      'parent' => {}
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'appendix'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'appendix',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 1,
      'line_nr' => {
        'file_name' => 'more_sections_than_nodes.texi',
        'line_nr' => 44,
        'macro' => ''
      },
      'number' => 'A',
      'parent' => {}
    },
    {
      'args' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'misc_arg'
        }
      ],
      'cmdname' => 'bye',
      'parent' => {}
    }
  ],
  'type' => 'document_root'
};
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[1]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_description'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[3]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'extra'}{'menu_entry_description'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[4];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'contents'}[4];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[3]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[4];
$result_trees{'more_sections_than_nodes'}{'contents'}[4]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[4]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[4]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[5]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[5];
$result_trees{'more_sections_than_nodes'}{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[5];
$result_trees{'more_sections_than_nodes'}{'contents'}[5]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[6]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[6];
$result_trees{'more_sections_than_nodes'}{'contents'}[6]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[6];
$result_trees{'more_sections_than_nodes'}{'contents'}[6]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[1]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[2]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[3]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[3]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[2]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'contents'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'contents'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[8];
$result_trees{'more_sections_than_nodes'}{'contents'}[8]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[9]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[9]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[9]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[9];
$result_trees{'more_sections_than_nodes'}{'contents'}[9]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[9];
$result_trees{'more_sections_than_nodes'}{'contents'}[9]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[10];
$result_trees{'more_sections_than_nodes'}{'contents'}[10]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[10]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[10]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[11]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[11]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[11];
$result_trees{'more_sections_than_nodes'}{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[11];
$result_trees{'more_sections_than_nodes'}{'contents'}[11]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[12]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[12]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[12]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[12];
$result_trees{'more_sections_than_nodes'}{'contents'}[12]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[12];
$result_trees{'more_sections_than_nodes'}{'contents'}[12]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[13]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[13]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[13]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[13];
$result_trees{'more_sections_than_nodes'}{'contents'}[13]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[13];
$result_trees{'more_sections_than_nodes'}{'contents'}[13]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[14]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[14]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[14]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[14];
$result_trees{'more_sections_than_nodes'}{'contents'}[14]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[14];
$result_trees{'more_sections_than_nodes'}{'contents'}[14]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[15]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[15]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[15]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[15];
$result_trees{'more_sections_than_nodes'}{'contents'}[15]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[15];
$result_trees{'more_sections_than_nodes'}{'contents'}[15]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[2];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[2]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[3];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[0]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[2]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[3]{'contents'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[17]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[17]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[17]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[17];
$result_trees{'more_sections_than_nodes'}{'contents'}[17]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[17];
$result_trees{'more_sections_than_nodes'}{'contents'}[17]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[18]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[18]{'args'}[0];
$result_trees{'more_sections_than_nodes'}{'contents'}[18]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[18];
$result_trees{'more_sections_than_nodes'}{'contents'}[18]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[18];
$result_trees{'more_sections_than_nodes'}{'contents'}[18]{'parent'} = $result_trees{'more_sections_than_nodes'};
$result_trees{'more_sections_than_nodes'}{'contents'}[19]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[19];
$result_trees{'more_sections_than_nodes'}{'contents'}[19]{'parent'} = $result_trees{'more_sections_than_nodes'};

$result_texis{'more_sections_than_nodes'} = '\\input texinfo @c -*-texinfo-*-

@setfilename more_sections_than_nodes.info

@node Top
@top top

@menu
* n c2::
* n c3::
* n c3 s1 s2::
@end menu

@chapter c1

@node n c2
@chapter c2

@section s1

@node n c3, n c3 s1 s2, n c2, Top
@chapter c3

@menu 
* n c3 s 2::
@end menu

@section C3 s1

@node n c3 s 2
@section c3 s2

@section c3 s3

@chapter c4

@section c3 s1

@subsection c3 s1 s1

@node n c3 s1 s2,,n c3,Top
@subsection c3 s1 s2

@appendix appendix

@bye
';


$result_texts{'more_sections_than_nodes'} = '
top
***

* n c2::
* n c3::
* n c3 s1 s2::

1 c1
****

2 c2
****

2.1 s1
======

3 c3
****

* n c3 s 2::

3.1 C3 s1
=========

3.2 c3 s2
=========

3.3 c3 s3
=========

4 c4
****

4.1 c3 s1
=========

4.1.1 c3 s1 s1
--------------

4.1.2 c3 s1 s2
--------------

Appendix A appendix
*******************

';

$result_sectioning{'more_sections_than_nodes'} = {
  'level' => -1,
  'section_childs' => [
    {
      'cmdname' => 'top',
      'extra' => {
        'associated_node' => {
          'cmdname' => 'node',
          'extra' => {
            'normalized' => 'Top',
            'spaces_before_argument' => ' '
          }
        },
        'spaces_before_argument' => ' '
      },
      'level' => 0,
      'section_childs' => [
        {
          'cmdname' => 'chapter',
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'level' => 1,
          'number' => 1,
          'section_up' => {},
          'toplevel_prev' => {},
          'toplevel_up' => {}
        },
        {
          'cmdname' => 'chapter',
          'extra' => {
            'associated_node' => {
              'cmdname' => 'node',
              'extra' => {
                'normalized' => 'n-c2',
                'spaces_before_argument' => ' '
              }
            },
            'spaces_before_argument' => ' '
          },
          'level' => 1,
          'number' => 2,
          'section_childs' => [
            {
              'cmdname' => 'section',
              'extra' => {
                'spaces_before_argument' => ' '
              },
              'level' => 2,
              'number' => '2.1',
              'section_up' => {}
            }
          ],
          'section_prev' => {},
          'section_up' => {},
          'toplevel_prev' => {},
          'toplevel_up' => {}
        },
        {
          'cmdname' => 'chapter',
          'extra' => {
            'associated_node' => {
              'cmdname' => 'node',
              'extra' => {
                'normalized' => 'n-c3',
                'spaces_before_argument' => ' '
              }
            },
            'spaces_before_argument' => ' '
          },
          'level' => 1,
          'number' => 3,
          'section_childs' => [
            {
              'cmdname' => 'section',
              'extra' => {
                'spaces_before_argument' => ' '
              },
              'level' => 2,
              'number' => '3.1',
              'section_up' => {}
            },
            {
              'cmdname' => 'section',
              'extra' => {
                'associated_node' => {
                  'cmdname' => 'node',
                  'extra' => {
                    'normalized' => 'n-c3-s-2',
                    'spaces_before_argument' => ' '
                  }
                },
                'spaces_before_argument' => ' '
              },
              'level' => 2,
              'number' => '3.2',
              'section_prev' => {},
              'section_up' => {}
            },
            {
              'cmdname' => 'section',
              'extra' => {
                'spaces_before_argument' => ' '
              },
              'level' => 2,
              'number' => '3.3',
              'section_prev' => {},
              'section_up' => {}
            }
          ],
          'section_prev' => {},
          'section_up' => {},
          'toplevel_prev' => {},
          'toplevel_up' => {}
        },
        {
          'cmdname' => 'chapter',
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'level' => 1,
          'number' => 4,
          'section_childs' => [
            {
              'cmdname' => 'section',
              'extra' => {
                'spaces_before_argument' => ' '
              },
              'level' => 2,
              'number' => '4.1',
              'section_childs' => [
                {
                  'cmdname' => 'subsection',
                  'extra' => {
                    'spaces_before_argument' => ' '
                  },
                  'level' => 3,
                  'number' => '4.1.1',
                  'section_up' => {}
                },
                {
                  'cmdname' => 'subsection',
                  'extra' => {
                    'associated_node' => {
                      'cmdname' => 'node',
                      'extra' => {
                        'normalized' => 'n-c3-s1-s2',
                        'spaces_before_argument' => ' '
                      }
                    },
                    'spaces_before_argument' => ' '
                  },
                  'level' => 3,
                  'number' => '4.1.2',
                  'section_prev' => {},
                  'section_up' => {}
                }
              ],
              'section_up' => {}
            }
          ],
          'section_prev' => {},
          'section_up' => {},
          'toplevel_prev' => {},
          'toplevel_up' => {}
        },
        {
          'cmdname' => 'appendix',
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'level' => 1,
          'number' => 'A',
          'section_prev' => {},
          'section_up' => {},
          'toplevel_prev' => {},
          'toplevel_up' => {}
        }
      ],
      'section_up' => {}
    }
  ]
};
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[1]{'section_childs'}[0]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[1];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[1]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[1]{'toplevel_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_childs'}[0]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_childs'}[1]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_childs'}[2]{'section_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_childs'}[1];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_childs'}[2]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[1];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'toplevel_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[1];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2]{'toplevel_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_childs'}[0]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_childs'}[0]{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_childs'}[0]{'section_childs'}[1]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_childs'}[0]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'toplevel_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[2];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3]{'toplevel_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[4]{'section_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[4]{'section_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[4]{'toplevel_prev'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[3];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_childs'}[4]{'toplevel_up'} = $result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0];
$result_sectioning{'more_sections_than_nodes'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'more_sections_than_nodes'};

$result_nodes{'more_sections_than_nodes'} = {
  'cmdname' => 'node',
  'extra' => {
    'associated_section' => {
      'cmdname' => 'top',
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'level' => 0
    },
    'normalized' => 'Top',
    'spaces_before_argument' => ' '
  },
  'menu_child' => {
    'cmdname' => 'node',
    'extra' => {
      'associated_section' => {
        'cmdname' => 'chapter',
        'extra' => {
          'spaces_before_argument' => ' '
        },
        'level' => 1,
        'number' => 2
      },
      'normalized' => 'n-c2',
      'spaces_before_argument' => ' '
    },
    'node_next' => {
      'cmdname' => 'node',
      'extra' => {
        'associated_section' => {
          'cmdname' => 'chapter',
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'level' => 1,
          'number' => 3
        },
        'normalized' => 'n-c3',
        'spaces_before_argument' => ' '
      },
      'menu_child' => {
        'cmdname' => 'node',
        'extra' => {
          'associated_section' => {
            'cmdname' => 'section',
            'extra' => {
              'spaces_before_argument' => ' '
            },
            'level' => 2,
            'number' => '3.2'
          },
          'normalized' => 'n-c3-s-2',
          'spaces_before_argument' => ' '
        },
        'node_up' => {}
      },
      'menus' => [
        {
          'cmdname' => 'menu',
          'extra' => {
            'end_command' => {
              'cmdname' => 'end',
              'extra' => {
                'command_argument' => 'menu',
                'spaces_before_argument' => ' ',
                'text_arg' => 'menu'
              }
            }
          }
        }
      ],
      'node_next' => {
        'cmdname' => 'node',
        'extra' => {
          'associated_section' => {
            'cmdname' => 'subsection',
            'extra' => {
              'spaces_before_argument' => ' '
            },
            'level' => 3,
            'number' => '4.1.2'
          },
          'normalized' => 'n-c3-s1-s2',
          'spaces_before_argument' => ' '
        },
        'node_prev' => {},
        'node_up' => {}
      },
      'node_prev' => {},
      'node_up' => {}
    },
    'node_prev' => {},
    'node_up' => {}
  },
  'menus' => [
    {
      'cmdname' => 'menu',
      'extra' => {
        'end_command' => {
          'cmdname' => 'end',
          'extra' => {
            'command_argument' => 'menu',
            'spaces_before_argument' => ' ',
            'text_arg' => 'menu'
          }
        }
      }
    }
  ],
  'node_next' => {}
};
$result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_next'}{'menu_child'}{'node_up'} = $result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_next'};
$result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_next'}{'node_next'}{'node_prev'} = $result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_next'};
$result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_next'}{'node_next'}{'node_up'} = $result_nodes{'more_sections_than_nodes'};
$result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'more_sections_than_nodes'}{'menu_child'};
$result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'more_sections_than_nodes'};
$result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_prev'} = $result_nodes{'more_sections_than_nodes'};
$result_nodes{'more_sections_than_nodes'}{'menu_child'}{'node_up'} = $result_nodes{'more_sections_than_nodes'};
$result_nodes{'more_sections_than_nodes'}{'node_next'} = $result_nodes{'more_sections_than_nodes'}{'menu_child'};

$result_menus{'more_sections_than_nodes'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top',
    'spaces_before_argument' => ' '
  },
  'menu_child' => {
    'cmdname' => 'node',
    'extra' => {
      'normalized' => 'n-c2',
      'spaces_before_argument' => ' '
    },
    'menu_next' => {
      'cmdname' => 'node',
      'extra' => {
        'normalized' => 'n-c3',
        'spaces_before_argument' => ' '
      },
      'menu_child' => {
        'cmdname' => 'node',
        'extra' => {
          'normalized' => 'n-c3-s-2',
          'spaces_before_argument' => ' '
        },
        'menu_up' => {},
        'menu_up_hash' => {
          'n-c3' => 1
        }
      },
      'menu_next' => {
        'cmdname' => 'node',
        'extra' => {
          'normalized' => 'n-c3-s1-s2',
          'spaces_before_argument' => ' '
        },
        'menu_prev' => {},
        'menu_up' => {},
        'menu_up_hash' => {
          'Top' => 1
        }
      },
      'menu_prev' => {},
      'menu_up' => {},
      'menu_up_hash' => {
        'Top' => 1
      }
    },
    'menu_up' => {},
    'menu_up_hash' => {
      'Top' => 1
    }
  }
};
$result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_next'}{'menu_child'}{'menu_up'} = $result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_next'};
$result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_next'}{'menu_next'}{'menu_prev'} = $result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_next'};
$result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_next'}{'menu_next'}{'menu_up'} = $result_menus{'more_sections_than_nodes'};
$result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_next'}{'menu_prev'} = $result_menus{'more_sections_than_nodes'}{'menu_child'};
$result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_next'}{'menu_up'} = $result_menus{'more_sections_than_nodes'};
$result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_up'} = $result_menus{'more_sections_than_nodes'};

$result_errors{'more_sections_than_nodes'} = [];


$result_floats{'more_sections_than_nodes'} = {};


1;
